@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -30,8 +30,8 @@ import sun.jvm.hotspot.utilities.Observable;
 import sun.jvm.hotspot.utilities.Observer;
 
 import sun.jvm.hotspot.debugger.Address;
-import sun.jvm.hotspot.gc.g1.HeapRegionClosure;
-import sun.jvm.hotspot.gc.g1.PrintRegionClosure;
+import sun.jvm.hotspot.gc.g1.G1HeapRegionClosure;
+import sun.jvm.hotspot.gc.g1.G1PrintRegionClosure;
 import sun.jvm.hotspot.gc.shared.CollectedHeap;
 import sun.jvm.hotspot.gc.shared.CollectedHeapName;
 import sun.jvm.hotspot.gc.shared.LiveRegionsClosure;
@@ -47,7 +47,7 @@ import sun.jvm.hotspot.tools.HeapSummary;
 // Mirror class for G1CollectedHeap.
 
 public class G1CollectedHeap extends CollectedHeap {
-    // HeapRegionManager _hrm;
+    // G1HeapRegionManager _hrm;
     private static long hrmFieldOffset;
     // MemRegion _g1_reserved;
     private static long g1ReservedFieldOffset;
@@ -55,11 +55,9 @@ public class G1CollectedHeap extends CollectedHeap {
     private static CIntegerField summaryBytesUsedField;
     // G1MonitoringSupport* _monitoring_support;
     private static AddressField monitoringSupportField;
-    // HeapRegionSet _old_set;
+    // G1HeapRegionSet _old_set;
     private static long oldSetFieldOffset;
-    // HeapRegionSet _archive_set;
-    private static long archiveSetFieldOffset;
-    // HeapRegionSet _humongous_set;
+    // G1HeapRegionSet _humongous_set;
     private static long humongousSetFieldOffset;
 
     static {
@@ -77,7 +75,6 @@ public class G1CollectedHeap extends CollectedHeap {
         summaryBytesUsedField = type.getCIntegerField("_summary_bytes_used");
         monitoringSupportField = type.getAddressField("_monitoring_support");
         oldSetFieldOffset = type.getField("_old_set").getOffset();
-        archiveSetFieldOffset = type.getField("_archive_set").getOffset();
         humongousSetFieldOffset = type.getField("_humongous_set").getOffset();
     }
 
@@ -93,9 +90,9 @@ public class G1CollectedHeap extends CollectedHeap {
         return hrm().length();
     }
 
-    public HeapRegionManager hrm() {
+    public G1HeapRegionManager hrm() {
         Address hrmAddr = addr.addOffsetTo(hrmFieldOffset);
-        return VMObjectFactory.newObject(HeapRegionManager.class, hrmAddr);
+        return VMObjectFactory.newObject(G1HeapRegionManager.class, hrmAddr);
     }
 
     public G1MonitoringSupport monitoringSupport() {
@@ -103,42 +100,48 @@ public class G1CollectedHeap extends CollectedHeap {
         return VMObjectFactory.newObject(G1MonitoringSupport.class, monitoringSupportAddr);
     }
 
-    public HeapRegionSetBase oldSet() {
+    public G1HeapRegionSetBase oldSet() {
         Address oldSetAddr = addr.addOffsetTo(oldSetFieldOffset);
-        return VMObjectFactory.newObject(HeapRegionSetBase.class, oldSetAddr);
+        return VMObjectFactory.newObject(G1HeapRegionSetBase.class, oldSetAddr);
     }
 
-    public HeapRegionSetBase archiveSet() {
-        Address archiveSetAddr = addr.addOffsetTo(archiveSetFieldOffset);
-        return VMObjectFactory.newObject(HeapRegionSetBase.class, archiveSetAddr);
-    }
-
-    public HeapRegionSetBase humongousSet() {
+    public G1HeapRegionSetBase humongousSet() {
         Address humongousSetAddr = addr.addOffsetTo(humongousSetFieldOffset);
-        return VMObjectFactory.newObject(HeapRegionSetBase.class, humongousSetAddr);
+        return VMObjectFactory.newObject(G1HeapRegionSetBase.class, humongousSetAddr);
     }
 
-    private Iterator<HeapRegion> heapRegionIterator() {
+    private Iterator<G1HeapRegion> heapRegionIterator() {
         return hrm().heapRegionIterator();
     }
 
-    public void heapRegionIterate(HeapRegionClosure hrcl) {
-        Iterator<HeapRegion> iter = heapRegionIterator();
+    public void heapRegionIterate(G1HeapRegionClosure hrcl) {
+        Iterator<G1HeapRegion> iter = heapRegionIterator();
         while (iter.hasNext()) {
-            HeapRegion hr = iter.next();
+            G1HeapRegion hr = iter.next();
             hrcl.doHeapRegion(hr);
         }
     }
 
+    public G1HeapRegion heapRegionForAddress(Address addr) {
+        Iterator<G1HeapRegion> iter = heapRegionIterator();
+        while (iter.hasNext()) {
+            G1HeapRegion hr = iter.next();
+            if (hr.isInRegion(addr)) {
+                return hr;
+            }
+        }
+        return null;
+    }
+
     public CollectedHeapName kind() {
         return CollectedHeapName.G1;
     }
 
     @Override
     public void liveRegionsIterate(LiveRegionsClosure closure) {
-        Iterator<HeapRegion> iter = heapRegionIterator();
+        Iterator<G1HeapRegion> iter = heapRegionIterator();
         while (iter.hasNext()) {
-            HeapRegion hr = iter.next();
+            G1HeapRegion hr = iter.next();
             closure.doLiveRegions(hr);
         }
     }
@@ -149,14 +152,14 @@ public class G1CollectedHeap extends CollectedHeap {
 
         tty.print("garbage-first heap");
         tty.print(" [" + mr.start() + ", " + mr.end() + "]");
-        tty.println(" region size " + (HeapRegion.grainBytes() / 1024) + "K");
+        tty.println(" region size " + (G1HeapRegion.grainBytes() / 1024) + "K");
 
         HeapSummary sum = new HeapSummary();
         sum.printG1HeapSummary(tty, this);
     }
 
     public void printRegionDetails(PrintStream tty) {
-        PrintRegionClosure prc = new PrintRegionClosure(tty);
+        G1PrintRegionClosure prc = new G1PrintRegionClosure(tty);
         heapRegionIterate(prc);
     }
 
